#ifndef _H_MIOT_LOG
#define _H_MIOT_LOG

#include <stdint.h>
#include <stdarg.h>

#include "SEGGER_RTT/SEGGER_RTT.h"

///////////////////////////////////////
// config
///////////////////////////////////////

#define MI_LOG_ENABLED       1
#define MI_LOG_COLORS_ENABLE 1

/**
 * Log error   level    :1
 * Log warning level    :2
 * Log info    level    :3
 * Log debug   level    :4
 */
#ifndef MI_LOG_LEVEL
#define MI_LOG_LEVEL 4
#endif

///////////////////////////////
// defines
///////////////////////////////

#define MI_LOG_LEVEL_ERROR        1U
#define MI_LOG_LEVEL_WARNING      2U
#define MI_LOG_LEVEL_INFO         3U
#define MI_LOG_LEVEL_DEBUG        4U

#ifndef MI_LOG_MODULE_NAME
#define MI_LOG_MODULE_NAME        ""
#endif

#if MI_LOG_COLORS_ENABLE
#define MI_LOG_COLOR_DEFAULT      "\x1B[0m"
#define MI_LOG_COLOR_BLACK        "\x1B[1;30m"
#define MI_LOG_COLOR_RED          "\x1B[1;31m"
#define MI_LOG_COLOR_GREEN        "\x1B[1;32m"
#define MI_LOG_COLOR_YELLOW       "\x1B[1;33m"
#define MI_LOG_COLOR_BLUE         "\x1B[1;34m"
#define MI_LOG_COLOR_MAGENTA      "\x1B[1;35m"
#define MI_LOG_COLOR_CYAN         "\x1B[1;36m"
#define MI_LOG_COLOR_WHITE        "\x1B[1;37m"
#else
#define MI_LOG_COLOR_DEFAULT
#define MI_LOG_COLOR_BLACK
#define MI_LOG_COLOR_RED
#define MI_LOG_COLOR_GREEN
#define MI_LOG_COLOR_YELLOW
#define MI_LOG_COLOR_BLUE
#define MI_LOG_COLOR_MAGENTA
#define MI_LOG_COLOR_CYAN
#define MI_LOG_COLOR_WHITE
#endif

#define MI_LOG_ERROR_COLOR   MI_LOG_COLOR_RED
#define MI_LOG_WARNING_COLOR MI_LOG_COLOR_YELLOW
#define MI_LOG_INFO_COLOR    MI_LOG_COLOR_DEFAULT
#define MI_LOG_DEBUG_COLOR   MI_LOG_COLOR_GREEN
#define MI_LOG_DEFAULT_COLOR MI_LOG_COLOR_DEFAULT

#define MI_LOG_BREAK      ": "

#define MI_ERROR_PREFIX   MI_LOG_ERROR_COLOR "[E] " MI_LOG_MODULE_NAME MI_LOG_BREAK
#define MI_WARNING_PREFIX MI_LOG_WARNING_COLOR "[W] " MI_LOG_MODULE_NAME MI_LOG_BREAK
#define MI_INFO_PREFIX    MI_LOG_INFO_COLOR "[I] " MI_LOG_MODULE_NAME MI_LOG_BREAK
#define MI_DEBUG_PREFIX   MI_LOG_DEBUG_COLOR "[D] " MI_LOG_MODULE_NAME MI_LOG_BREAK

int mible_log_printf(const char *sFormat, ...);
int mible_log_hexdump(void *array_base, uint16_t array_size);

#if MI_LOG_ENABLED==1
    #define MI_PRINTF(...)                      mible_log_printf(__VA_ARGS__)
    #define MI_HEXDUMP(array_base, array_size)  mible_log_hexdump(array_base, array_size)
#else
    #define MI_PRINTF(...)
    #define MI_HEXDUMP(array_base, array_size)
#endif

#define MI_LOG_INTERNAL_ERROR(_fmt_, ...)                                       \
do {                                                                            \
    if (MI_LOG_LEVEL >= MI_LOG_LEVEL_ERROR)                                     \
    {                                                                           \
        MI_PRINTF(MI_ERROR_PREFIX _fmt_ MI_LOG_DEFAULT_COLOR, ##__VA_ARGS__);   \
    }                                                                           \
} while(0)

#define MI_LOG_INTERNAL_WARNING(_fmt_, ...)                                     \
do {                                                                            \
    if (MI_LOG_LEVEL >= MI_LOG_LEVEL_WARNING)                                   \
    {                                                                           \
        MI_PRINTF(MI_WARNING_PREFIX _fmt_ MI_LOG_DEFAULT_COLOR, ##__VA_ARGS__); \
    }                                                                           \
} while(0)

#define MI_LOG_INTERNAL_INFO(_fmt_, ...)                                        \
do {                                                                            \
    if (MI_LOG_LEVEL >= MI_LOG_LEVEL_INFO)                                      \
    {                                                                           \
        MI_PRINTF(MI_INFO_PREFIX _fmt_ MI_LOG_DEFAULT_COLOR, ##__VA_ARGS__);    \
    }                                                                           \
} while(0)

#define MI_LOG_INTERNAL_DEBUG(_fmt_, ...)                                       \
do {                                                                            \
    if (MI_LOG_LEVEL >= MI_LOG_LEVEL_DEBUG)                                     \
    {                                                                           \
        MI_PRINTF(MI_DEBUG_PREFIX _fmt_ MI_LOG_DEFAULT_COLOR, ##__VA_ARGS__);   \
    }                                                                           \
} while(0)

#define MI_LOG_INTERNAL_HEXDUMP(p_data, len)                                    \
do {                                                                            \
    if (MI_LOG_LEVEL >= MI_LOG_LEVEL_DEBUG)                                     \
    {                                                                           \
        MI_HEXDUMP(p_data, len);                                                \
    }                                                                           \
} while(0)

#if MI_LOG_ENABLED
    #define MI_LOG_ERROR(...)   MI_LOG_INTERNAL_ERROR(__VA_ARGS__)
    #define MI_LOG_WARNING(...) MI_LOG_INTERNAL_WARNING(__VA_ARGS__)
    #define MI_LOG_INFO(...)    MI_LOG_INTERNAL_INFO(__VA_ARGS__)
    #define MI_LOG_DEBUG(...)   MI_LOG_INTERNAL_DEBUG(__VA_ARGS__)
    #define MI_LOG_HEXDUMP(...) MI_LOG_INTERNAL_HEXDUMP(__VA_ARGS__)
#else
    #define MI_LOG_ERROR(...)
    #define MI_LOG_WARNING(...)
    #define MI_LOG_INFO(...)
    #define MI_LOG_DEBUG(...)
    #define MI_LOG_HEXDUMP(...)
#endif

#endif // !_H_MIOT_LOG