# coding:utf-8
import os
import sys
import subprocess
import logging
from datetime import datetime
# Parameter description:
# $1 - Application project path: apps\tuyaos_zigbee_light_sample
# $2 - Application project name: tuyaos_zigbee_light_sample
# $3 - Application project version: 1.0.0
# $4 - Application project command: build/clean
# python build_app.py apps\tuyaos_zigbee_light_sample tuyaos_zigbee_light_sample 1.0.0 clean

# Get the path to the current python interpreter
PYTHON_PATH = sys.executable

APP_PATH = sys.argv[1]
APP_NAME = sys.argv[2]
APP_VERSION = sys.argv[3]
BUILD_COMMAND = 'build'

if len(sys.argv) == 5:
    BUILD_COMMAND = sys.argv[4]

# print("./{time}.log")
# app project product name and path
CURR_PATH = os.getcwd()
SCRIPT_PATH = 'tools\scripts'
APP_BUILD_PATH = os.path.join(APP_PATH, '_build')
# print(datetime.datetime.now().strftime('%Y_%m_%d_%H_%M_%S'))
print(APP_BUILD_PATH)

now = datetime.now()
timestr = now.strftime("%Y_%m_%d_%H_%M_%S")
log_path=os.path.join(APP_PATH,".\log")
if os.path.exists(log_path):
    pass
else: 
    os.makedirs(log_path)
    print('create log path')

log_file=os.path.join(log_path, '%s.log'%timestr)
print(log_file)


logging.basicConfig(filename=log_file,
                    format='%(asctime)s  %(filename)s : %(levelname)s  %(message)s',
                    level=logging.INFO)
logging.info("PYTHON_PATH:  %s"%PYTHON_PATH)
logging.info("APP_PATH: %s"%APP_PATH)
logging.info("APP_NAME: %s"%APP_NAME)
logging.info("APP_VERSION:  %s"%APP_VERSION)
logging.info("BUILD_COMMAND:  %s"%BUILD_COMMAND)
logging.info("SCRIPT_PATH:  %s"%SCRIPT_PATH)

# check 
if len(sys.argv) < 3 or APP_PATH=='' or APP_NAME=='' or APP_VERSION=='':
    print("Script parameter error !!!")
    logging.error("Script parameter error !!!")


if BUILD_COMMAND == "build":
    os.chdir(SCRIPT_PATH)
    python_path = PYTHON_PATH + ' app_prepare.py'
    para = "%s \"%s\" \"%s\" \"%s\" \"%s\" \"%s\""%(python_path, APP_PATH, APP_NAME, APP_VERSION, timestr+'.log', BUILD_COMMAND)
    logging.info("subprocess.call:  %s"%para)
    ret = subprocess.call(para)
    if ret != 0:
        print("app_prepare.py execution failed !!!")
        logging.error("app_prepare.py execution failed: %s.!!!"%ret)
        sys.exit(1)
    os.chdir(CURR_PATH)

logging.info("app_prepare.py execution successful.")
os.chdir(APP_BUILD_PATH)
python_path = PYTHON_PATH + ' build.py'
para = "%s \"%s\" \"%s\" \"%s\" \"%s\" \"%s\""%(python_path, APP_PATH, APP_NAME, APP_VERSION,timestr+'.log', BUILD_COMMAND)
logging.info("subprocess.call:  %s"%para)
ret = subprocess.call(para)
if ret != 0:
    print("build.py execution failed !!!:%d"%ret)
    logging.error("build.py execution failed: %s.!!!"%ret)
    sys.exit(1)
os.chdir(CURR_PATH)
logging.info("build.py execution successful.")

