 /**
 * @file tkl_binding_table.h
 * @brief Common process - binding table manager
 * @version 1.0.0
 * @date 2021-05-13
 *
 * @copyright Copyright 2021-2022 Tuya Inc. All Rights Reserved.
 *
 */

#ifndef __TKL_BINDING_TABLE_H__
#define __TKL_BINDING_TABLE_H__


#ifdef __cplusplus
    extern "C" {
#endif

#include "tuya_cloud_types.h"


typedef UINT8_T EUI64_T[8];

/*
 * zigbee binding table type
 */
typedef enum {
    TUYA_UNUSED_BINDING     = 0,    ///< binding table entry is not used
    TUYA_UNICAST_BINDING    = 1,    ///< unicast binding, 64bits address is destination MAC
    TUYA_MULTICAST_BINDING  = 3,    ///< multicast binding, 16bits address is group id
} TKL_BIND_TYPE_E;

/*
 * zigbee binding table
 */
typedef struct {
    TKL_BIND_TYPE_E  type;          ///< binding type
    UINT8_T          local_ep;      ///< local endpoint
    UINT8_T          remote_ep;     ///< remote endpoint
    UINT16_T         cluster;       ///< cluster id
    // 64bits destination MAC, for unicasts.
    // 16bits multicast group id, for multicasts.
    EUI64_T          address;       ///< binding address
} TKL_BINDING_TABLE_T;

/**
 * @brief add binding entry to table
 *
 * @param[in]   entry: binding entry
 * @return  0: success  Other: fail
 */
BOOL_T tkl_zg_add_binding(TKL_BINDING_TABLE_T *entry);

/**
 * @brief remove binding entry from table
 *
 * @param[in]   entry: binding entry
 * @return  0: success  Other: fail
 */
BOOL_T tkl_zg_remove_binding(TKL_BINDING_TABLE_T *entry);

/**
 * @brief remove clear binding table
 *
 * @param[in]   none
 * @return  0: success  Other: fail
 */
BOOL_T tkl_zg_clear_all_binding(VOID_T);


#ifdef __cplusplus
}
#endif

#endif
