/**
 * @file tkl_sdk_compatible.h
 * @brief This is tkl_sdk_compatible file
 * @version 1.0
 * @date 2022-09-15
 *
 * @copyright Copyright 2021-2031 Tuya Inc. All Rights Reserved.
 *
 */

#ifndef __TKL_SDK_COMPATIBLE_H__
#define __TKL_SDK_COMPATIBLE_H__

#include "tuya_cloud_types.h"
#include "tuya_error_code.h"

#ifdef __cplusplus
extern "C" {
#endif

/***********************************************************************
 ********************* constant ( macro and enum ) *********************
 **********************************************************************/
// #define COMPA_BIT_CHECK(a,bit)    (a&bit)
// #define COMPA_BIT_SET(a,bit)      (a|=bit)
// #define COMPA_BIT_CLR(a,bit)      (a&=(~bit))
#define KV_ID_USER_FLASH        0u
#define KV_ID_MAIN_FLASH        1u

#define COMPA_STATE_IDLE 0xFF
enum{
    COMPA_STATE_MAIN_FLASH =0x01,//RAW FLASH
    COMPA_STATE_ATTRIBUTE =0x02,
    COMPA_STATE_MF_INFO =0x04,
    COMPA_STATE_USER_FLASH =0x08,//user flash
    COMPA_STATE_USER_TOKEN =0x10,//ECC,AUTHKEY
    COMPA_STATE_TABLE =0x20,
    // COMPA_STATE_NWK_RECOVERY =0x20,

};

typedef enum {
    TKL_NV_SUCC = 0,
    TKL_NV_INVALID_MODULS,
    TKL_NV_INVALID_ID ,
    TKL_NV_ITEM_NOT_FOUND,
    TKL_NV_NOT_ENOUGH_SAPCE,
    TKL_NV_ITEM_LEN_NOT_MATCH,
    TKL_NV_CHECK_SUM_ERROR,
} TKL_NV_STATUS_E;
/***********************************************************************
 ********************* struct ******************************************
 **********************************************************************/
// typedef TKL_NV_STATUS_E (* NV_WRITE_CB)(UINT8_T id, UINT8_T item_id, UINT16_T len, UINT8_T *buf);
// typedef TKL_NV_STATUS_E (* KV_WRITE_CB)(UINT8_T key_id, UINT16_T len, UINT8_T *buf);
// typedef UINT_T (* OEM_WRITE_CB)(UINT8_T* buff, UINT_T size);
// typedef struct{
//     NV_WRITE_CB nv_write_cb;
//     KV_WRITE_CB kv_write_cb;
//     OEM_WRITE_CB oem_write_cb;
// } SDKCOMP_INIT_T;

/***********************************************************************
 ********************* variable ****************************************
 **********************************************************************/


/***********************************************************************
 ********************* function ****************************************
 **********************************************************************/
/**
 * @brief 
 * 
 * @return VOID_T 
 */
UINT16_T tkl_sdkcomp_main_flash_read(UINT8_T *data, UINT16_T len);
/**
 * @brief 
 * 
 * @return INT8_T 
 */
INT8_T tkl_sdkcomp_get_first_flag(void);
/**
 * @brief 
 * 
 * @param state 
 * @return VOID_T 
 */
extern VOID_T tkl_sdkcomp_mflash_flag_set(UINT8_T state);
/**
 * @brief 
 * 
 * @return VOID_T 
 */
extern UINT8_T tkl_sdkcomp_mflash_flag_get(VOID_T);
/**
 * @brief 
 * 
 * @return UINT8_T 
 */
UINT8_T tkl_sdkcomp_state_load(VOID_T);
/**
 * @brief 
 * 
 * @param is_init 
 * @param state 
 * @return UINT8_T 
 */
UINT8_T tkl_sdkcomp_state_update(UINT8_T is_init, UINT8_T state);
/**
 * @brief 
 * 
 * @param state 
 * @return UINT8_T 
 */
UINT8_T tkl_sdkcomp_state_checkbit(UINT8_T state);
// /**
//  * @brief 
//  * 
//  * @return VOID_T 
//  */
// VOID_T tkl_sdkcomp_state_reset(VOID_T);
/**
 * @brief 
 * 
 * @return UINT8_T 
 */
UINT8_T tkl_sdkcomp_covert_attribute_to_tuyaos(void);
/**
 * @brief 
 * 
 * @return UINT16_T 
 */
UINT16_T tkl_sdkcomp_scenes_recovery(VOID_T);
/**
 * @brief 
 * 
 * @param data 
 * @param len 
 * @return UINT8_T 
 */
INT16_T tkl_sdkcomp_mf_info_read(UINT8_T * data, UINT16_T len);
/**
 * @brief 
 * 
 * @param data 
 * @param len 
 * @return UINT8_T 
 */
UINT8_T tkl_sdkcomp_user_flash_token_read(UINT8_T *data, UINT8_T len);
/**
 * @brief 
 * 
 * @param data 
 * @param len 
 * @return UINT8_T 
 */
UINT8_T tkl_sdkcomp_ecc_flash_token_read(UINT8_T *data, UINT8_T len);
/**
 * @brief < this is a weak function you can rewrite this API in upper layer >
 * 
 * @return UINT16_T 
 */
UINT16_T tkl_sdkcomp_main_flash_length_callback(VOID_T);
/**
 * @brief 
 * 
 * @return VOID_T 
 */
VOID_T tkl_sdkcomp_release_attribute_source(VOID_T);
/**
 * @brief 
 * 
 * @return VOID_T 
 */
VOID_T tkl_sdkcomp_complete(VOID_T);
#ifdef __cplusplus
}
#endif

#endif /* __TKL_SDK_COMPATIBLE_H__ */

