 /**
 * @file tal_reporting.h
 * @brief Common process - reporting
 * @version 1.0.0
 * @date 2021-09-19
 *
 * @copyright Copyright 2018-2021 Tuya Inc. All Rights Reserved.
 *
 */
#ifndef __TAL_REPORTING_H__
#define __TAL_REPORTING_H__


#ifdef __cplusplus
    extern "C" {
#endif

#include "tuya_cloud_types.h"
#include "tuya_zigbee_stack.h"


/**
 * @enum the direction of the reporting table
 */
typedef enum {
    TAL_REPORT_DIRECTION_REPORTED = 0x00,   ///< The direction of active reporting
    TAL_REPORT_DIRECTION_RECEIVED = 0x01,   ///< The direction of receiving data
} TAL_REPORT_DIREC_E;

/**
 * @enum zigbee reporting table structure
 */
typedef struct {
    TAL_REPORT_DIREC_E direction;   ///< reporting direction
    UINT8_T  ep_id;                 ///< endpoint id
    UINT16_T cluster_id;            ///< cluster id, see TUYA_CLUSTER_ID_E
    UINT16_T attr_id;               ///< attribute id
    ZG_CLUSTER_MASK_E mask;         ///< reporting cluster mask
    UINT16_T manuf_code;            ///< manufacturer code
    union {
        struct {
            UINT16_T min_interval;  ///< mini reporting interval, measured in seconds
            UINT16_T max_interval;  ///< max reporting interval, measured in seconds
            UINT_T   report_change; ///< mini change to the attribute that will result in a report being sent
        } reported;
        struct {
            UINT16_T source_addr;   ///< node id of the source of the received reports
            UINT8_T  endpoint;      ///< remote endpoint from which the attribute is reported
            UINT16_T timeout;       ///< max expected time between reports, measured in seconds
        } received;
    } data;
} TAL_REPORT_TABLE_T;

/**
 * @brief zigbee reporting init
 *
 * @param[in]   entery:    point to report table list
 * @param[in]   sums:      sum of report table item
 * @return  OPRT_OK on success. Others on error, please refer to tuya_error_code.h
 */
OPERATE_RET tal_zg_reporting_init(TAL_REPORT_TABLE_T *entery, UINT8_T sums);

/**
 * @brief zigbee add reporting item to report table
 *
 * @param[in]   entery:    point to report item
 * @return  TRUE: sucess, FALSE: error
 */
BOOL_T tal_zg_add_reporting_entry(TAL_REPORT_TABLE_T *entery);

/**
 * @brief zigbee add reporting item to report table
 *
 * @param[in]   entery:    point to report item
 * @return  TRUE: sucess, FALSE: error
 */
VOID_T tal_zg_load_default_reporting_table(VOID_T);

/**
 * @brief zigbee clear report table
 *
 * @param[in]   none
 * @return  none
 */
VOID_T tal_zg_clear_reporting_table(VOID_T);


#ifdef __cplusplus
}
#endif

#endif

